==> seedsui-react-5.8.81.tgz: package/lib/Cascader/DistrictMain/utils/defaultSetValueType.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t.return && (u = t.return(), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
import testMunicipality from "./testMunicipality";
import testPrefecture from "./testPrefecture";
import testCountry from "./testCountry";
import testProvince from "./testProvince";
import testCity from "./testCity";
import testDistrict from "./testDistrict";
import testStreet from "./testStreet";
import testNodeData from "./testNodeData";

// 主方法: 匹配当前选中项的类型, tabs支持array和object两种方式, array匹配将会更准确
function defaultSetValueType(tabs, config) {
  var _ref = config || {},
    list = _ref.list,
    isCountry = _ref.isCountry,
    isProvince = _ref.isProvince,
    isMunicipality = _ref.isMunicipality,
    isPrefecture = _ref.isPrefecture,
    isCity = _ref.isCity,
    isDistrict = _ref.isDistrict,
    isStreet = _ref.isStreet;
  // Array type parameter is invalid
  if (Array.isArray(tabs) && !tabs.length) {
    return null;
  }
  var _iterator = _createForOfIteratorHelper(tabs.entries()),
    _step;
  try {
    for (_iterator.s(); !(_step = _iterator.n()).done;) {
      var _step$value = _slicedToArray(_step.value, 2),
        index = _step$value[0],
        current = _step$value[1];
      // No id is invalid
      if (!(current !== null && current !== void 0 && current.id)) {
        continue;
      }

      // 直辖市判断
      if (testMunicipality(current, isMunicipality)) {
        current.type = ['province', 'city', 'municipality'];
        continue;
      } else if (testCountry(current, isCountry)) {
        current.type = ['country'];
        continue;
      } else if (testProvince(current, isProvince)) {
        current.type = ['province'];
        continue;
      }
      // 直筒子市判断
      else if (testPrefecture(current, isPrefecture)) {
        current.type = ['city', 'prefecture'];
        continue;
      } else if (testCity(current, isCity)) {
        current.type = ['city'];
        continue;
      } else if (testStreet(current, isStreet)) {
        current.type = ['street'];
        continue;
      } else if (testDistrict(current, isDistrict)) {
        current.type = ['district'];
        continue;
      }

      // 不是省市，但在list中，则认为是区；不在list中，则认为是街道(街道在list中, 会有isStreet，所以在isStreet时就返回了)
      var type = testNodeData(current, list);
      if (type) {
        current.type = [type];
        continue;
      }

      // 有国的情况
      if (testCountry(tabs[0], isCountry)) {
        // 省市将在上面被匹配到
        // if (index === 1) {
        //   current.type = ['province']
        //   continue
        // }
        // if (index === 2) {
        //   current.type = ['city']
        //   continue
        // }
        if (index === 3) {
          // 直辖市或者直筒子市, 第3级为街道
          if (tabs[2].type.includes('municipality') || tabs[2].type.includes('prefecture')) {
            current.type = ['street'];
          } else {
            current.type = ['district'];
          }
          continue;
        }
        if (index === 4) {
          current.type = ['street'];
          continue;
        }
      } else {
        // 省市将在上面被匹配到
        // if (index === 0) {
        //   current.type = ['province']
        //   continue
        // }
        // if (index === 1) {
        //   current.type = ['city']
        //   continue
        // }
        if (index === 2) {
          // 直辖市或者直筒子市, 第3级为街道
          if (tabs[1].type.includes('municipality') || tabs[2].type.includes('prefecture')) {
            current.type = ['street'];
          } else {
            current.type = ['district'];
          }
          continue;
        }
        if (index === 3) {
          current.type = ['street'];
          continue;
        }
      }
      continue;
    }
  } catch (err) {
    _iterator.e(err);
  } finally {
    _iterator.f();
  }
  return tabs;
}
export default defaultSetValueType;

==> seedsui-react-5.8.90.tgz: package/lib/Cascader/DistrictMain/utils/defaultSetValueType.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t.return && (u = t.return(), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
import testMunicipality from "./testMunicipality";
import testPrefecture from "./testPrefecture";
import testCountry from "./testCountry";
import testProvince from "./testProvince";
import testCity from "./testCity";
import testDistrict from "./testDistrict";
import testStreet from "./testStreet";
import testNodeData from "./testNodeData";

// 主方法: 匹配当前选中项的类型, tabs支持array和object两种方式, array匹配将会更准确
function defaultSetValueType(tabs, config) {
  var _ref = config || {},
    list = _ref.list,
    isCountry = _ref.isCountry,
    isProvince = _ref.isProvince,
    isMunicipality = _ref.isMunicipality,
    isPrefecture = _ref.isPrefecture,
    isCity = _ref.isCity,
    isDistrict = _ref.isDistrict,
    isStreet = _ref.isStreet;
  // Array type parameter is invalid
  if (!Array.isArray(tabs) || !tabs.length) {
    return null;
  }
  var _iterator = _createForOfIteratorHelper(tabs.entries()),
    _step;
  try {
    for (_iterator.s(); !(_step = _iterator.n()).done;) {
      var _step$value = _slicedToArray(_step.value, 2),
        index = _step$value[0],
        current = _step$value[1];
      // No id is invalid
      if (!(current !== null && current !== void 0 && current.id)) {
        continue;
      }

      // 直辖市判断
      if (testMunicipality(current, isMunicipality)) {
        current.type = ['province', 'city', 'municipality'];
        continue;
      } else if (testCountry(current, isCountry)) {
        current.type = ['country'];
        continue;
      } else if (testProvince(current, isProvince)) {
        current.type = ['province'];
        continue;
      }
      // 直筒子市判断
      else if (testPrefecture(current, isPrefecture)) {
        current.type = ['city', 'prefecture'];
        continue;
      } else if (testCity(current, isCity)) {
        current.type = ['city'];
        continue;
      } else if (testStreet(current, isStreet)) {
        current.type = ['street'];
        continue;
      } else if (testDistrict(current, isDistrict)) {
        current.type = ['district'];
        continue;
      }

      // 获取对应列表中的节点类型
      var type = testNodeData(current, list);
      if (type) {
        current.type = [type];
        continue;
      }

      // 有国的情况
      if (testCountry(tabs[0], isCountry)) {
        // 省市将在上面被匹配到
        if (index === 1) {
          current.type = ['province'];
          continue;
        }
        if (index === 2) {
          // 直辖市的下级为区
          if (tabs[1].type.includes('municipality')) {
            current.type = ['district'];
          } else {
            current.type = ['city'];
          }
          continue;
        }
        if (index === 3) {
          // 直辖市或者直筒子市, 第3级为街道
          if (tabs[1].type.includes('municipality') || tabs[2].type.includes('prefecture')) {
            current.type = ['street'];
          } else {
            current.type = ['district'];
          }
          continue;
        }
        if (index === 4) {
          current.type = ['street'];
          continue;
        }
      } else {
        // 省市将在上面被匹配到
        if (index === 0) {
          current.type = ['province'];
          continue;
        }
        if (index === 1) {
          // 直辖市的下级为区
          if (tabs[0].type.includes('municipality')) {
            current.type = ['district'];
          } else {
            current.type = ['city'];
          }
          continue;
        }
        if (index === 2) {
          // 直辖市或者直筒子市, 第3级为街道
          if (tabs[0].type.includes('municipality') || tabs[1].type.includes('prefecture')) {
            current.type = ['street'];
          } else {
            current.type = ['district'];
          }
          continue;
        }
        if (index === 3) {
          current.type = ['street'];
          continue;
        }
      }
      continue;
    }
  } catch (err) {
    _iterator.e(err);
  } finally {
    _iterator.f();
  }
  return tabs;
}
export default defaultSetValueType;
